@@ -10,6 +10,7 @@
 #include "plasma_nm_kded.h"
 
 #include <QDBusPendingReply>
+#include <QPointer>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -184,3 +185,5 @@ void ModemMonitor::onSendPinArrived(QDBusPendingCallWatcher *watcher)
 
     watcher->deleteLater();
 }
+
+#include "moc_modemmonitor.cpp"
